@@ -5,12 +5,10 @@ from pathlib import Path
 
 import click
 
-from scapy import Worker
-
+from ..core.worker import Worker
+from .settings import DEFAULT_ROOT_CA_FILE, DEFAULT_WORKER_FILE
 from .utils import Printer
 
-HOME = Path.home()
-
 
 @click.command()
 @click.option(
@@ -33,14 +31,14 @@ HOME = Path.home()
     "-j",
     "--js",
     envvar="WORKER_FILE",
-    default=Path("./build/index.js"),
+    default=DEFAULT_WORKER_FILE,
     type=click.Path(exists=True),
     help="Worker file location",
 )
 @click.option(
     "-n",
     "--name",
-    envvar="WEB_TITLE",
+    envvar="CA_NAME",
     type=str,
     help="CA Server's Name",
 )
@@ -63,7 +61,7 @@ HOME = Path.home()
     "-r",
     "--root",
     envvar="ROOT_CERT",
-    default=(HOME / ".step/certs/root_ca.crt"),
+    default=DEFAULT_ROOT_CA_FILE,
     type=click.Path(exists=True),
     help="CA Root Certificate file in PEM or DER format",
 )
@@ -75,7 +73,7 @@ def deploy(
     fingerprint: str,
     ca_url: str,
     root: Path,
-):
+) -> None:
     """Deploy a cloudflare worker to publish CA Certificate."""
     printer = Printer()
     printer.working("Initialising deployment process", animate=False)
